==> comptechsoft-vue-foundation-1.0.10.tgz: package/src/~compvuetech/Components/Controls/Textboxes/Base/Textbox.js <==
import Control from "../../Control";

class Textbox extends Control {

    constructor(name) {
        super(name)

        this.type = 'text'

        this.label = 'My Label (' + this.name + ')'
        this.placeholder = 'My placeholder (' + this.name + ')'
        this.maxlength = null
        this.step = null
        this.decimal = null

        this.vue = null
        this.plugin = null
    }

    SetPlaceholder(value) {
        this.placeholder = value
        return this
    }

    SetLabel(value) {
        this.label = value
        return this
    }

    SetType(value) {
        this.type = value
        return this
    }

    SetStep(value) {
        this.step = value
        return this
    }

    SetMaxlength(value) {
        this.maxlength = value
        return this
    }

    SetDecimal(value) {
        this.decimal = value
        return this
    }

    // https://github.com/RobinHerbots/inputmask
    CreateDecimalInputMaskPlugin(vue) {
        this.vue = vue
        let i = setInterval( () => {
            let jq = $('#input-' + this.id)
            if(jq.length == 1)
            {
                clearInterval(i)
                let options = {
                    alias: 'decimal',
                    groupSeparator: ',',
                    radixPoint: '.',
                    autoGroup: true,
                    digitsOptional: false, 
                    rightAlign : true,
                    clearMaskOnLostFocus: true,
                    autoUnmask: true,
                }
                _.each(this.decimal, (value, key) => {
                    options[key] = value
                })
                this.instance = jq.inputmask('decimal', options); 
                this.instance.on('input', function(e) {
                    vue.$emit('input', e.target.value)
                })
            }
        }, 100)
    }
}

export default Textbox

==> comptechsoft-vue-foundation-1.0.12.tgz: package/src/~compvuetech/Components/Controls/Textboxes/Base/Textbox.js <==
import Control from "../../Control";

class Textbox extends Control {

    constructor(name) {
        super(name)

        this.type = 'text'

        this.label = null
        this.placeholder = null
        this.maxlength = null
        this.readonly = null
        this.step = null
        this.decimal = null

        this.vue = null
        this.plugin = null
    }

    SetPlaceholder(value) {
        this.placeholder = value
        return this
    }

    SetLabel(value) {
        this.label = value
        return this
    }

    SetType(value) {
        this.type = value
        return this
    }

    SetStep(value) {
        this.step = value
        return this
    }

    SetMaxlength(value) {
        this.maxlength = value
        return this
    }

    SetDecimal(value) {
        this.decimal = value
        return this
    }

    Readonly() {
        this.readonly = true
        return this
    }

    // https://github.com/RobinHerbots/inputmask
    CreateDecimalInputMaskPlugin(vue) {
        this.vue = vue
        let i = setInterval( () => {
            let jq = $('#input-' + this.id)
            if(jq.length == 1)
            {
                clearInterval(i)
                let options = {
                    alias: 'decimal',
                    groupSeparator: ',',
                    radixPoint: '.',
                    autoGroup: true,
                    digitsOptional: false, 
                    rightAlign : true,
                    clearMaskOnLostFocus: true,
                    autoUnmask: true,
                }
                _.each(this.decimal, (value, key) => {
                    options[key] = value
                })
                this.instance = jq.inputmask('decimal', options); 
                this.instance.on('input', function(e) {
                    vue.$emit('input', e.target.value)
                })
            }
        }, 100)
    }

    /**
     * Daca avem valoare in textbox ==> la primirea focusului se selecteaza automat
     */
    ApplySelectOnFocus() {
        let i = setInterval( () => {
            let jq = $('#input-' + this.id)
            if(jq.length == 1)
            {
                clearInterval(i)
                jq.focus(function(){
                    let value = $(this).val()
                    console.log('Focusssssss......' + this.id + '=' + value)
                    if(value.length > 0)
                    {
                        setTimeout( () => {
                            jq.select()
                        }, 10)
                    }
                })
            }
        }, 50)
    }
}

export default Textbox
